(************************************************************************************
Filename    :   Win32_RoomTiny_Main.cpp
Content     :   First-person view test application for Oculus Rift
Created     :   18th Dec 2014
Authors     :   Tom Heath
Copyright   :   Copyright 2012 Oculus, Inc. All Rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*************************************************************************************)
/// This sample shows how to vary IPD (interpupillary distance).  Again, this
/// should have been set correctly behind the scenes, from the Oculus config tool,
/// but if objects are perceived at different sizes than expected, then wrong IPD
/// can be the cause, so this sample shows how you can vary it manually,
/// ideally for debug purposes.
unit UDemoAdjustIPD;

interface

procedure Main;

implementation

uses
  Winapi.D3D11, Winapi.DxgiFormat, OVR_CAPI_D3D, UDirectXAppUtil, UBasicVR;

type
  TAdjustIPD = class(TBasicVR)
  public
    constructor Create;
    procedure MainLoop; override;
  end;

constructor TAdjustIPD.Create;
begin
  inherited Create('Adjust IPD');
end;

procedure TAdjustIPD.MainLoop;
var
  newIPD: Single;
  eye: NativeInt;
begin
  Layer[0] := TVRLayer.Create(Session);

  while HandleMessages do
  begin
    ActionFromInput;

    newIPD := 0.064;
    if DIRECTX.Key['1'] then newIPD := 0.05;
    if DIRECTX.Key['2'] then newIPD := 0.06;
    if DIRECTX.Key['3'] then newIPD := 0.07;
    if DIRECTX.Key['4'] then newIPD := 0.08;
    Layer[0].GetEyePoses(nil, nil, @newIPD);

    for eye := 0 to 1 do
    begin
      Layer[0].RenderSceneToEyeBuffer(MainCam, RoomScene, eye);
    end;

    Layer[0].PrepareLayerHeader;
    DistortAndPresent(1);
  end;
end;

procedure Main;
var
  app: TAdjustIPD;
begin
  app := TAdjustIPD.Create;
  try
    ExitCode := app.Run;
  finally
    app.Free;
  end;
end;

end.