(************************************************************************************
Filename    :   Win32_RoomTiny_Main.cpp
Content     :   First-person view test application for Oculus Rift
Created     :   18th Dec 2014
Authors     :   Tom Heath
Copyright   :   Copyright 2012 Oculus, Inc. All Rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*************************************************************************************)
/// A simple piece of sample code to show how to detect a user tapping
/// on the Rift.
unit UDemoTapDetection;

interface

procedure Main;

implementation

uses
  Winapi.Windows, System.Math.Vectors, OVR_CAPI, UDirectXAppUtil, UBasicVR, UControlMethods;

type
  TTapDetection = class(TBasicVR)
  private
    color_mode: Integer;
  public
    constructor Create;
    procedure MainLoop; override;
  end;

constructor TTapDetection.Create;
begin
  inherited Create('Tap Detection');
end;

procedure TTapDetection.MainLoop;
var
  trackingState: TOvrTrackingState;
  singleTap: Boolean;
  eye: NativeInt;
begin
  Layer[0] := TVRLayer.Create(Session);

  while HandleMessages do
  begin
    ActionFromInput;
    trackingState := Layer[0].GetEyePoses;

    // Change color mode if single tapped
    singleTap := WasItTapped(trackingState.HeadPose.LinearAcceleration);
    if singleTap then
      Inc(color_mode);

    for eye := 0 to 1 do
    begin
      // Render world according to color mode
      case color_mode mod 4 of
        0: Layer[0].RenderSceneToEyeBuffer(MainCam, RoomScene, eye);
        1: Layer[0].RenderSceneToEyeBuffer(MainCam, RoomScene, eye, nil, nil, 1, 1, 1, 0, 0);
        2: Layer[0].RenderSceneToEyeBuffer(MainCam, RoomScene, eye, nil, nil, 1, 1, 0, 1, 0);
        3: Layer[0].RenderSceneToEyeBuffer(MainCam, RoomScene, eye, nil, nil, 1, 1, 0, 0, 1);
      end;
    end;

    Layer[0].PrepareLayerHeader;
    DistortAndPresent(1);
  end;
end;

procedure Main;
var
  app: TTapDetection;
begin
  app := TTapDetection.Create;
  try
    ExitCode := app.Run;
  finally
    app.Free;
  end;
end;

end.